--------------------------------------------------------------------------------------------------------------
--
-- Module     : SIMS Database SQL Server 2005
-- Platform   : SIMS
-- Area       : DBUpgrade Database Patch
-- Copyright  : (c) Capita Education Services 2005-2009
--            : This code has been written by Capita Education Services for use within its own SIMS systems.
--            : It is unpublished proprietary work, and as such it is illegal for it to be reproduced by any
--            : means or used without the express written permission of Capita Education Services.
-- Patch ID   : 11328
--
--------------------------------------------------------------------------------------------------------------

-- Check this is within the acceptible range
  IF NOT EXISTS(
	SELECT 1 
	FROM	sims.db_version_info
	WHERE	schema_version BETWEEN '3.61.870' AND '3.62.999')
  BEGIN
    DECLARE @error_msg2 VARCHAR(100)
    SET @error_msg2 = CHAR(10) + CHAR(13) + 'This patch is not applicable to this database version.' + CHAR(10) + CHAR(13)
	raiserror(@error_msg2, 18, 1)
  END

-- This is a RunOnce patch - check its not already been applied.
ELSE IF EXISTS(SELECT 1 
	        FROM   sims.db_update_log 
	        WHERE	patch_id = 11328)
  BEGIN
    DECLARE @error_msg1 VARCHAR(100)
    SET @error_msg1 = CHAR(10) + CHAR(13) + 'This patch has already been run on the database and cannot be run again.' + CHAR(10) + CHAR(13)
	raiserror(@error_msg1, 18, 1) 
  END

GO
-- START PATCH CODE



-- START PATCH SCRIPT 1

-- BAV License and setup
-- Note: Run SIMS Services patch to show the Web Setups menu

/* This is a license patch for Bulk address validation */

if exists (	select 1 from sims.db_version_info  vi
	inner join sims.sims_region r
	on r.region_id = vi.region_id
	where region_code IN ('ENG', 'WALES', 'SCOT')
	)
begin
	update sims.db_process_class
	set 	licensed = 'T'
	,	readonly = 0
	where process_name in 
	(
	  'BAVScheduleAddresses'
	, 'BAVBrowseAgent'
	, 'BAVBrowseAgency'
	, 'BAVApplicationBrowser'
	, 'BAVEnquiryBrowser'
	, 'BAVOtherSchoolBrowser'
	, 'BAVBrowseStaff'
	, 'BAVBrowseStudents'
	, 'BAVAddressDetail'
	, 'ScheduleWindowsTask'
	, 'ScheduleWindowsTaskBrowser'
	)
end

if not exists (select 1 from sims.sims_service where code = 'BAV')
begin
    -- This sets up the correct web service for BAV
    insert into sims.sims_service
    (code, name, system, active, internet, priority, provider, url, country_id, type_id, requires_authentication, service_user_name, service_password)
    values
    ('BAV', 'BulkAddressValidationService', 1, 1, 1, 3, 'CES', 'http://bav.capita-cso.co.uk/ValidateUKAddress.asmx', 215, 4, 0, 
    'SIMS_SCHOOL', 'mkDzPej/ckDDGDjbu2nbTCAt6OevwVCcz7gl8e/vsCFN8dPfNX5yYg==')

    -- This sets up the number of addresses that BAV will send each night
    if exists(select 1 from sysobjects where name = 'bav_setup' and type = 'U')
    begin
        update sims.bav_setup
        set number_of_addresses = 1000
    end

end





-- END PATCH SCRIPT 1
GO


-- END PATCH CODE



-- Record that this patch has been updated
INSERT INTO sims.db_update_log
(
	patch_id,
	update_id,
	successful,
	description,
	update_type,
	date_applied
)
VALUES
(
	11328,
	1,
	'T',
	'SIMS Licence Activator Patch: Bulk Address Validation',
	'U',
	GetDate()
)

